@@ -4,11 +4,11 @@ import logging
 import grpc
 from google.protobuf import empty_pb2
 
-from apeman.model.openapi import apemanOpenApi_pb2
-from apeman.model.openapi import apemanOpenApi_pb2_grpc
+from apeman.model.openapi import apeman_open_api_pb2
+from apeman.model.openapi import apeman_open_api_pb2_grpc
 
 
-class ApemanModelServer(apemanOpenApi_pb2_grpc.ApemanModelOpenApiServicer):
+class ApemanModelServer(apeman_open_api_pb2_grpc.ApemanModelOpenApiServicer):
 
     def Report(self, request, context):
         taskId = request.modelInstanceTaskId
@@ -27,12 +27,12 @@ class ApemanModelServer(apemanOpenApi_pb2_grpc.ApemanModelOpenApiServicer):
         taskId = request.modelInstanceId
         print('taskId: ', taskId)
 
-        return apemanOpenApi_pb2.GetModelEndpointResponse(endpoint='http://svc-test.apeman')
+        return apeman_open_api_pb2.GetModelEndpointResponse(endpoint='http://svc-test.apeman')
 
 
 async def serve() -> None:
     server = grpc.aio.server()
-    apemanOpenApi_pb2_grpc.add_ApemanModelOpenApiServicer_to_server(
+    apeman_open_api_pb2_grpc.add_ApemanModelOpenApiServicer_to_server(
         ApemanModelServer(), server)
     server.add_insecure_port('[::]:9090')
     await server.start()
